# Leetcode Query
A library for retriving informations from Leetcode

## Install 🚧

## Usage
### Retriving User Submissions
``` python
from leetquery.user import get_submissions

submissions = get_submissions(username="syhaung", limits)
```
return value:
```
["question1", "question2", ...]
```